==> haskell-doctest-driver-gen-0.3.0.8-10-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-driver-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-driver-gen
version:              0.3.0.8
visibility:           public
id:                   doctest-driver-gen-0.3.0.8-Ihvcrkeva17DqzHIKQHyIy
key:                  doctest-driver-gen-0.3.0.8-Ihvcrkeva17DqzHIKQHyIy
license:              BSD-3-Clause
copyright:            (C) Hexirp 2017-2023
maintainer:           https://github.com/Hexirp/doctest-driver-gen/issues
author:               Hexirp
homepage:             https://github.com/Hexirp/doctest-driver-gen#readme
synopsis:             Generate driver file for doctest'\''s cabal integration
description:
    doctest-driver-gen is a doctest'\''s driver file generator.
    It lets you automatically generate driver file for
    doctest'\''s cabal integration.

category:             Testing
abi:                  a1186b7518691c8afceece91d95d26c9
exposed:              True
exposed-modules:      Test.DocTest.Gen
import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctest-driver-gen-0.3.0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctest-driver-gen-0.3.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-driver-gen
hs-libraries:         HSdoctest-driver-gen-0.3.0.8-Ihvcrkeva17DqzHIKQHyIy
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-doctest-driver-gen/html/doctest-driver-gen.haddock

haddock-html:         /usr/share/doc/haskell-doctest-driver-gen/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-driver-gen-0.3.0.8-12-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-driver-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-driver-gen
version:              0.3.0.8
visibility:           public
id:                   doctest-driver-gen-0.3.0.8-EtLqyKEMgusCJwhBjQM19e
key:                  doctest-driver-gen-0.3.0.8-EtLqyKEMgusCJwhBjQM19e
license:              BSD-3-Clause
copyright:            (C) Hexirp 2017-2023
maintainer:           https://github.com/Hexirp/doctest-driver-gen/issues
author:               Hexirp
homepage:             https://github.com/Hexirp/doctest-driver-gen#readme
synopsis:             Generate driver file for doctest'\''s cabal integration
description:
    doctest-driver-gen is a doctest'\''s driver file generator.
    It lets you automatically generate driver file for
    doctest'\''s cabal integration.

category:             Testing
abi:                  bf9b4dc3a9508180b32e512c0e238e32
exposed:              True
exposed-modules:      Test.DocTest.Gen
import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctest-driver-gen-0.3.0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctest-driver-gen-0.3.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-driver-gen
hs-libraries:         HSdoctest-driver-gen-0.3.0.8-EtLqyKEMgusCJwhBjQM19e
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-doctest-driver-gen/html/doctest-driver-gen.haddock

haddock-html:         /usr/share/doc/haskell-doctest-driver-gen/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
